@extends('frame')
@section('title', 'The Bad Space|About')
@section('main-content')
    @parent
    <section>
        <article>
            <h2 id="what">What is The Bad Space?</h2>
            <p>The Bad Space arose from a need to identify instances that house bad actors, are poorly moderated, and/or contain inappropriate/offensive content (CSAM, hate speech, fascist ideology, etc.) that puts marginalized communities at risk.</p>
            <p>It is an extension of the <strong>#fediblock</strong> hashtag - orginally created by <a href="https://www.artistmarciax.com/">Artist Marcia X</a> with additional support from <a href="https://digital.rooting.garden">Ginger</a> to provide a catalog of instances that seek to cause harm and reduce the quality of experience in the fediverse.</p>
            <p>The searchable online catalog is built and maintained by <a href="https://roiskinda.cool/profile.html">Ro</a>. The repo can be found <a href="https://koodu.h-i.works/projects/thebadspace">here</a>.</p>
            <p>Custom silence and suspend icons graciously provided by <a href="https://rage.love/@puf">puf</a>.</p>

            <h2 id="how">How does it work?</h2>
            <p>The Bad Space is a collaboration of communities, referred to as Current Sources, committed to actively moderating against racism, sexism, heterosexism, transphobia, ableism, casteism, or religion.</p>
            <p>These communities have permitted The Bad Space to ingest their respective blocklists detailing their silences and suspension to create a composite directory of sites that engage in the behavior(s) listed in the section above. For each behavior, the directory of locations can be searched and, through The Bad Space's public API, integrated into external services.</p>

            <h2>Adding Locations</h2>
            <p>Current Sources continually review the #fediblock hashtag and update their silences and suspensions when warranted. If an instance meets the criteria of a Current Source to be suspended or silenced, The Bad Space will automatically be updated according to said Current Sources' curated data.</p>
            <p>For an instance to be listed on The Bad Space, at least two (2) Current Sources must have that location silenced and/or suspended. Instances will not display in the directory until two (2) Current Sources have taken moderation action against them.</p>

            <h2>Removing Locations</h2>
            <p>Locations that are displayed in The Bad Space may petition to be removed from the catalog by sending an appeal request to The Bad Space. The appeal process is outlined <a href="/appeals">here</a>.</p>

            <h3 class="strong">Current Sources:</h3>

            <h4>Maston:</h4>
            <ul>
                @foreach($sources as $source)
                    @if($source->format == 'json')
                        <li><a href="https://{{$source->url}}">{{$source->url}}</a></li>
                    @else
                        <li>None</li>
                    @endif
                @endforeach
            </ul>

            <h4>Custom CSV</h4>
            <ul>
                @foreach($sources as $source)
                    @if($source->format == 'csv')
                        <li><a href="{{$source->url}}">{{$source->url}}</a></li>
                    @else
                        <li>None</li>
                    @endif
                @endforeach
            </ul>

            <h2>How do I use it?</h2>
            <p>The Bad Space is meant to be a resource for anyone looking to improve the quality of their online experience by creating a tool that catalogs sources for harassment and abuse. There are several options for how it can be used.</p>

            <h3>Search</h3>
            <p>To see if a site is listed in the database, use the <a href="/">search feature</a> to search for that URL. If it is in the database, information for that instance will be returned and associated instances if applicable.</p>

            <h3>CSV Exports</h3>
            <p>For a list of the current locations being tracked, click on one of the links below to download a dynamically generated CSV file that can be consumed as a blocklist. More formats will be added over time.</p>
            <p><a href="/exports/mastodon">For Mastodon</a></p>

            <h3>API</h3>
            <p>The Bad Space has a public api that can be used to search the database programatically and return results in the JSON format. The API can be accsess at <code>https://thebad.space/api/v1/search</code> by posting a JSON object with the following format: <code>{"url":"search.url"}</code>. Data from API request will be returned in the follow format:</p>

<pre>
<code>{
    data:{
        "listingCount":1,
          "locations":
          [
            {
              "url":"search.url",
              "name":"Instance Name",
              "description":"instance description",
              "link":"bad-space-instance-link"
            }
          ]
    }
}</code>
</pre>
      </article>
    </section>
@endsection
